class FunctionalSchema:

    def __init__(self, filters,q_filters):  # TODO
        self.path = self.PATH
